#
# spec file for package qore-yaml-module
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define qore_version 1.0.10
%define src_name module-yaml-release-%{qore_version}
%define module_api %(qore --latest-module-api 2>/dev/null)
Name:           qore-yaml-module
# for version base see CMakeLists.txt, tags are done for each qore release
Version:        0.7.0+qore%{qore_version}
Release:        bp154.1.56
Summary:        YAML module for Qore
License:        LGPL-2.1-or-later OR GPL-2.0-or-later OR MIT
Group:          Development/Languages/Misc
URL:            https://www.qore.org/
Source:         https://github.com/qorelanguage/module-yaml/archive/refs/tags/release-%{qore_version}.tar.gz#/%{src_name}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libtool
BuildRequires:  libyaml-devel
BuildRequires:  qore
BuildRequires:  qore-devel >= %{qore_version}
Requires:       qore-module(abi)%{?_isa} = %{module_api}
Suggests:       %{name}-doc = %{version}

%description
This package contains the yaml module for the Qore Programming Language.

YAML is a flexible and concise human-readable data serialization format.

%package doc
Summary:        Documentation and examples for the Qore yaml module
Group:          Development/Languages/Misc
Requires:       %{name} = %{version}

%description doc
This package contains the HTML documentation and example programs for the Qore
yaml module.

%prep
%setup -q -n %{src_name}
find examples -type f|xargs chmod 644

%build
autoreconf -fi
%configure \
%ifarch x86_64 ppc64 ppc64le s390x aarch64
  --enable-64bit \
%endif
  --disable-debug
%make_build

%install
mkdir -p %{buildroot}%{_datadir}/doc/qore-yaml-module
%make_install
# Documentation needs the new built modules
export QORE_MODULE_DIR=%{buildroot}/%{_libdir}/qore-modules:%{buildroot}%{_datadir}/qore-modules
make html-local
%make_install install-html-local
%fdupes %{buildroot}%{_datadir}/qore-yaml-module

%files
%license COPYING.LGPL COPYING.MIT
%{_libdir}/qore-modules/*
%{_datadir}/qore-modules/*

%files doc
%doc README RELEASE-NOTES
%doc %{_datadir}/qore-yaml-module

%changelog
* Thu Oct 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.7.0 for Qore 1.0.10
  * Fixed module namespace paths
  * Fixed deserializing string values
  * Fixed handling serialization errors in YAML-RPC responses
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Revert last changes, version is not the git tag!
  Tag describes the qore version this module supports, base version
  is set inside the CMakeLists.txt
- Update to version 0.7.0 with qore release 0.9.15
  * Fix: single quoted string
  * allow connections to be created dynamically over the network
  * Support QoreValue API
  * Bug fixes
  * https://github.com/qorelanguage/module-yaml/compare/v0.6...release-0.9.15
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.0.0
  * https://github.com/qorelanguage/module-yaml/compare/v0.6...release-1.0.0
* Sat Dec 19 2020 sarah.kriesch@opensuse.org
- enable s390x as an architecture in spec file
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6:
  * improved the description for the DESERIALIZATION-ERROR exception for
  non-deserializable message bodies from HTTP servers with error responses (issue
  1033) added the YamlRpcConnection class to the YamlRpcClient module updated the
  DataStreamClient module for complex types and new internal RestClient API
  changes (issue 2073) updated the DataStreamUtil module for complex types
  fixed a bug deserializing single-quoted strings; also serialized "!number"
  values will always include the tag to avoid potential future ambiguity (issue
  2343) improved argument error messages with RPC calls in the YamlRpcHandler
  module (issue 2573)
  * new user modules for DataStream protocol support: YAML-encoded HTTP chunked
  transfers where each chunk is a unique data entity DataStreamClient user module
  DataStreamRequestHandler user module
  DataStreamUtil user module
  * user modules moved to top-level qore module directory from version-specific
  module directory since they are valid for multiple versions of qore date/time
  values (yaml !!timestamp type) are now always returned in the current time zone
  locale so that time zone rules can be applied to deserialized dates; previously
  time zone information was always lost which could cause errors when performing
  date arithmetic on deserialized yaml dates
  * fixed bugs deserializing canonically-encoded YAML strings; arbitrary-precision
  numeric values were deserialized with their precision values ignored and
  floating point +/-inf were deserialized as zero deprecated old camel-case names
  and implemented new function names confirming to the standard naming convention
  for functions
* Mon Aug 31 2015 normand@linux.vnet.ibm.com
- add --enable-64bit as already done for other qore-*-module
* Wed Jul 30 2014 petr@yarpen.cz
- migrated to OBS file layout
